#
# Cookbook:: ambari-chef
# Recipe:: python3
#
# The MIT License (MIT)
#
# Copyright:: 2018, Ryan Hansohn
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

# python3 upgrade pips
bash 'python3_upgrade_pips' do
  code 'python3 -m pip install --upgrade pip setuptools wheel'
  action :nothing
end

# python3 install packages
if node['python']['python3']['install']
  package 'python3_install' do
    package_name node['python']['python3']['packages']
    action :install
    notifies :run, 'bash[python3_upgrade_pips]', :immediately
  end
end

# python3 install pips
if node['python']['python3']['pips'].any?
  node['python']['python3']['pips'].each do |pip|
    bash "python3_install_pip_#{pip}" do
      code "python3 -m pip install '#{pip}'"
      action :run
    end
  end
end
